@@ -2,6 +2,8 @@
 # Plone CatalogTool
 #
 import re
+import time
+import urllib
 
 from Products.CMFCore.CatalogTool import CatalogTool as BaseTool
 from Products.CMFCore.permissions import ManagePortal
@@ -19,11 +21,15 @@ from Products.CMFCore.utils import _getAuthenticatedUser
 from Products.CMFCore.utils import _checkPermission
 from Products.CMFCore.CatalogTool import _mergedLocalRoles
 from Products.CMFCore.interfaces.portal_catalog \
-        import IndexableObjectWrapper as IIndexableObjectWrapper
+        import IndexableObjectWrapper as z2IIndexableObjectWrapper
+from Products.CMFCore.interfaces import IIndexableObjectWrapper
 from Products.CMFPlone.PloneBaseTool import PloneBaseTool
-from Products.CMFPlone.interfaces.NonStructuralFolder import INonStructuralFolder
+from Products.CMFPlone.interfaces import INonStructuralFolder
+from Products.CMFPlone.interfaces.NonStructuralFolder import \
+     INonStructuralFolder as z2INonStructuralFolder
 from Products.CMFPlone.utils import base_hasattr
 from Products.CMFPlone.utils import safe_callable
+from Products.CMFPlone.utils import log_deprecated
 from OFS.IOrderSupport import IOrderedContainer
 from ZODB.POSException import ConflictError
 
@@ -33,6 +39,8 @@ from AccessControl.Permissions import manage_zcatalog_entries as ManageZCatalogE
 from AccessControl.Permissions import search_zcatalog as SearchZCatalog
 from AccessControl.PermissionRole import rolesForPermissionOn
 
+from zope.interface import implements
+
 _marker = object()
 
 
@@ -65,7 +73,9 @@ class ExtensibleIndexableObjectWrapper(object):
     **kwargs - additional keyword arguments
     """
 
-    __implements__ = IIndexableObjectWrapper
+    __implements__ = z2IIndexableObjectWrapper
+
+    implements(IIndexableObjectWrapper)
 
     def __init__(self, vars, obj, portal, registry = _eioRegistry, **kwargs):
         self._vars = vars
@@ -123,7 +133,7 @@ num_sort_regex = re.compile('\d+')
 
 def sortable_title(obj, portal, **kwargs):
     """ Helper method for to provide FieldIndex for Title.
-    
+
     >>> from Products.CMFPlone.CatalogTool import sortable_title
 
     >>> self.folder.setTitle('Plone42 _foo')
@@ -223,19 +233,54 @@ def is_folderish(obj, **kwargs):
     """Should this item be treated as a folder?
 
     Checks isPrincipiaFolderish, as well as the INonStructuralFolder
-    interface.
+    interfaces.
 
-    >>> from Products.CMFPlone.CatalogTool import is_folderish
+      >>> from Products.CMFPlone.CatalogTool import is_folderish
+      >>> from Products.CMFPlone.interfaces import INonStructuralFolder
+      >>> from Products.CMFPlone.interfaces.NonStructuralFolder import INonStructuralFolder as z2INonStructuralFolder
+      >>> from zope.interface import directlyProvidedBy, directlyProvides
+
+    A Folder is folderish generally::
+      >>> is_folderish(self.folder)
+      True
+
+    But if we make it an INonStructuralFolder it is not::
+      >>> base_implements = directlyProvidedBy(self.folder)
+      >>> directlyProvides(self.folder, INonStructuralFolder, directlyProvidedBy(self.folder))
+      >>> is_folderish(self.folder)
+      False
+      
+    Now we revert our interface change and apply the z2 no-folderish interface::
+      >>> directlyProvides(self.folder, base_implements)
+      >>> is_folderish(self.folder)
+      True
+      >>> z2base_implements = self.folder.__implements__
+      >>> self.folder.__implements__ = z2base_implements + (z2INonStructuralFolder,)
+      >>> is_folderish(self.folder)
+      False
+
+    We again revert the interface change and check to make sure that
+    PrincipiaFolderish is respected::
+      >>> self.folder.__implements__ = z2base_implements
+      >>> is_folderish(self.folder)
+      True
+      >>> self.folder.isPrincipiaFolderish = False
+      >>> is_folderish(self.folder)
+      False
 
-    >>> is_folderish(self.folder)
-    True
     """
     # If the object explicitly states it doesn't want to be treated as a
     # structural folder, don't argue with it.
-    if INonStructuralFolder.isImplementedBy(obj):
+    folderish = bool(getattr(aq_base(obj), 'isPrincipiaFolderish', False))
+    if not folderish:
+        return False
+    elif INonStructuralFolder.providedBy(obj):
+        return False
+    elif z2INonStructuralFolder.isImplementedBy(obj):
+        # BBB: for z2 interface compat
         return False
     else:
-        return bool(getattr(aq_base(obj), 'isPrincipiaFolderish', False))
+        return folderish
 
 registerIndexableAttribute('is_folderish', is_folderish)
 
@@ -272,64 +317,9 @@ class CatalogTool(PloneBaseTool, BaseTool):
 
     def __init__(self):
         ZCatalog.__init__(self, self.getId())
+        log_deprecated("CatalogTool._initIndexes is deprecated, please use a GenericSetup profile instead.")
         self._initIndexes()
 
-    security.declarePublic('enumerateIndexes')
-    def enumerateIndexes(self):
-
-        idxs = ( ('Subject', 'KeywordIndex')
-               , ('Creator', 'FieldIndex')
-               , ('Date', 'DateIndex')
-               , ('Type', 'FieldIndex')
-               , ('created', 'DateIndex')
-               , ('effective', 'DateIndex')
-               , ('expires', 'DateIndex')
-               , ('modified', 'DateIndex')
-               , ('allowedRolesAndUsers', 'KeywordIndex')
-               , ('review_state', 'FieldIndex')
-               , ('in_reply_to', 'FieldIndex')
-               , ('meta_type', 'FieldIndex')
-               , ('id', 'FieldIndex')
-               , ('getId', 'FieldIndex')
-               , ('path', 'ExtendedPathIndex')
-               , ('portal_type', 'FieldIndex')
-               , ('getObjPositionInParent', 'FieldIndex')
-               , ('is_folderish', 'FieldIndex')
-               , ('is_default_page', 'FieldIndex')
-               )
-        return tuple([(n, t, None) for n, t in idxs])
-
-    security.declarePublic('enumerateColumns')
-    def enumerateColumns(self):
-        """Return a sequence of schema names to be cached.
-
-        Creator is deprecated and may go away, use listCreators!
-        """
-        return ( 'Subject'
-               , 'Title'
-               , 'Description'
-               , 'Type'
-               , 'review_state'
-               , 'Creator'
-               , 'listCreators'
-               , 'Date'
-               , 'getIcon'
-               , 'created'
-               , 'effective'
-               , 'expires'
-               , 'modified'
-               , 'CreationDate'
-               , 'EffectiveDate'
-               , 'ExpirationDate'
-               , 'ModificationDate'
-               , 'getId'
-               , 'portal_type'
-               # plone metadata
-               , 'id', # BBB to be removed in Plone 2.5
-               'getObjSize',
-               'exclude_from_nav',
-               )
-
     def _removeIndex(self, index):
         """Safe removal of an index.
         """
@@ -338,58 +328,6 @@ class CatalogTool(PloneBaseTool, BaseTool):
         except:
             pass
 
-    def manage_afterAdd(self, item, container):
-        self._createTextIndexes(item, container)
-
-    def _createTextIndexes(self, item, container):
-        """In addition to the standard indexes we need to create
-           'SearchableText', 'Title' and 'Description' as ZCTextIndex instance.
-        """
-
-        class args:
-            def __init__(self, **kw):
-                self.__dict__.update(kw)
-            def keys(self):
-                return self.__dict__.keys()
-
-        # This if-clause still looks somewhat scary
-        if item is self and not hasattr(aq_base(self), 'plone_lexicon'):
-
-            # We need to remove the indexes to keep the tests working...baaah
-            for idx in ('SearchableText', 'Title', 'Description'):
-                self._removeIndex(idx)
-
-            self.manage_addProduct['ZCTextIndex'].manage_addLexicon(
-                'plone_lexicon',
-                elements=[
-                    args(group='Case Normalizer', name='Case Normalizer'),
-                    args(group='Stop Words', name=" Don't remove stop words"),
-                    args(group='Word Splitter', name="Unicode Whitespace splitter"),
-                ]
-                )
-
-            extra = args(doc_attr='SearchableText',
-                         lexicon_id='plone_lexicon',
-                         index_type='Okapi BM25 Rank')
-            self.manage_addIndex('SearchableText', 'ZCTextIndex', extra=extra)
-
-            extra = args(doc_attr='Description',
-                         lexicon_id='plone_lexicon',
-                         index_type='Okapi BM25 Rank')
-            self.manage_addIndex('Description', 'ZCTextIndex', extra=extra)
-
-            extra = args(doc_attr='Title',
-                         lexicon_id='plone_lexicon',
-                         index_type='Okapi BM25 Rank')
-            self.manage_addIndex('Title', 'ZCTextIndex', extra=extra)
-
-    security.declareProtected(ManagePortal, 'migrateIndexes')
-    def migrateIndexes(self):
-        """Recreate all indexes.
-        """
-        self._initIndexes()
-        self._createTextIndexes()
-
     def _listAllowedRolesAndUsers(self, user):
         """Makes sure the list includes the user's groups.
         """
@@ -425,17 +363,8 @@ class CatalogTool(PloneBaseTool, BaseTool):
             vars = {}
         portal = aq_parent(aq_inner(self))
         w = ExtensibleIndexableObjectWrapper(vars, object, portal=portal)
-        try:
-            # pghandler argument got added in Zope 2.8
-            ZCatalog.catalog_object(self, w, uid, idxs,
-                                    update_metadata, pghandler=pghandler)
-        except TypeError:
-            try:
-                # update_metadata argument got added somewhere into
-                # the Zope 2.6 line (?)
-                ZCatalog.catalog_object(self, w, uid, idxs, update_metadata)
-            except TypeError:
-                ZCatalog.catalog_object(self, w, uid, idxs)
+        ZCatalog.catalog_object(self, w, uid, idxs,
+                                update_metadata, pghandler=pghandler)
 
     security.declareProtected(SearchZCatalog, 'searchResults')
     def searchResults(self, REQUEST=None, **kw):
@@ -445,7 +374,7 @@ class CatalogTool(PloneBaseTool, BaseTool):
         This version uses the 'effectiveRange' DateRangeIndex.
 
         It also accepts a keyword argument show_inactive to disable
-        effectiveRange checking entirely even for those withot portal
+        effectiveRange checking entirely even for those without portal
         wide AccessInactivePortalContent permission.
         """
         kw = kw.copy()
@@ -456,31 +385,49 @@ class CatalogTool(PloneBaseTool, BaseTool):
 
         if not show_inactive and not _checkPermission(AccessInactivePortalContent, self):
             kw['effectiveRange'] = DateTime()
-            if kw.has_key('effective'):
-                del kw['effective']
-            if kw.has_key('expires'):
-                del kw['expires']
 
         return ZCatalog.searchResults(self, REQUEST, **kw)
 
+    __call__ = searchResults
+
     security.declareProtected(ManageZCatalogEntries, 'clearFindAndRebuild')
     def clearFindAndRebuild(self):
         """Empties catalog, then finds all contentish objects (i.e. objects
-           with a reindexObject method), and reindexes them.
-           This may take a long time."""
+           with an indexObject method), and reindexes them.
+           This may take a long time.
+        """
+        def indexObject(obj, path):
+            if (base_hasattr(obj, 'indexObject') and
+                safe_callable(obj.indexObject)):
+                try:
+                    obj.indexObject()
+                except TypeError:
+                    # Catalogs have 'indexObject' as well, but they
+                    # take different args, and will fail
+                    pass
         self.manage_catalogClear()
         portal = aq_parent(aq_inner(self))
-        for path, obj in portal.ZopeFind(portal, search_sub=True):
-            if base_hasattr(obj, 'reindexObject') and \
-                    safe_callable(obj.reindexObject):
-                try:
-                    obj.reindexObject()
-                except TypeError:
-                    # Catalogs have this method as well, but they take
-                    # different args, and will fail
-                    pass
+        portal.ZopeFindAndApply(portal, search_sub=True, apply_func=indexObject)
 
-    __call__ = searchResults
+    security.declareProtected(ManageZCatalogEntries, 'manage_catalogRebuild')
+    def manage_catalogRebuild(self, RESPONSE=None, URL1=None):
+        """Clears the catalog and indexes all objects with an 'indexObject' method.
+           This may take a long time.
+        """
+        elapse = time.time()
+        c_elapse = time.clock()
+
+        self.clearFindAndRebuild()
+
+        elapse = time.time() - elapse
+        c_elapse = time.clock() - c_elapse
+
+        if RESPONSE is not None:
+            RESPONSE.redirect(
+              URL1 + '/manage_catalogAdvanced?manage_tabs_message=' +
+              urllib.quote('Catalog Rebuilt\n'
+                           'Total time: %s\n'
+                           'Total CPU time: %s' % (`elapse`, `c_elapse`)))
 
 CatalogTool.__doc__ = BaseTool.__doc__
 
