@@ -1,12 +1,16 @@
+import PIL
+from cStringIO import StringIO
 from DateTime import DateTime
 from Products.CMFCore.utils import getToolByName, _checkPermission
 from Products.CMFDefault.MembershipTool import MembershipTool as BaseTool
 from Products.CMFPlone import ToolNames
+from Products.CMFPlone.utils import scale_image
 from Products.CMFPlone.utils import _createObjectByType
 from OFS.Image import Image
 from AccessControl import ClassSecurityInfo, getSecurityManager
 from Globals import InitializeClass, DTMLFile
 from zExceptions import BadRequest
+from ZODB.POSException import ConflictError
 from AccessControl.SecurityManagement import noSecurityManager
 from Acquisition import aq_base, aq_parent, aq_inner
 from Products.CMFCore.permissions import ManagePortal
@@ -15,19 +19,10 @@ from Products.CMFCore.permissions import SetOwnProperties
 from Products.CMFCore.permissions import SetOwnPassword
 from Products.CMFCore.permissions import View
 from Products.CMFPlone.PloneBaseTool import PloneBaseTool
+from Products.CMFPlone.log import log
 
 default_portrait = 'defaultUser.gif'
 
-DEFAULT_MEMBER_CONTENT = """\
-Default page for %s
-
-  This is the default document created for you when
-  you joined this community.
-
-  To change the content just click the 'edit'
-  tab above.
-"""
-
 _marker = object()
 
 class MembershipTool(PloneBaseTool, BaseTool):
@@ -43,6 +38,11 @@ class MembershipTool(PloneBaseTool, BaseTool):
 
     __implements__ = (PloneBaseTool.__implements__, BaseTool.__implements__, )
 
+    manage_options = (BaseTool.manage_options +
+                      ( { 'label' : 'Portraits'
+                     , 'action' : 'manage_portrait_fix'
+                     },))
+
     # TODO I'm not quite sure why getPortalRoles is declared 'Managed'
     #    in CMFCore.MembershipTool - but in Plone we are not so anal ;-)
     security.declareProtected(View, 'getPortalRoles')
@@ -50,6 +50,9 @@ class MembershipTool(PloneBaseTool, BaseTool):
     security.declareProtected(ManagePortal, 'manage_mapRoles')
     manage_mapRoles = DTMLFile('www/membershipRolemapping', globals())
 
+    security.declareProtected(ManagePortal, 'manage_portrait_fix')
+    manage_portrait_fix = DTMLFile('www/portrait_fix', globals())
+
     security.declareProtected(ManagePortal, 'manage_setMemberAreaType')
     def manage_setMemberAreaType(self, type_name, REQUEST=None):
         """ ZMI method to set the home folder type by its type name.
@@ -84,9 +87,10 @@ class MembershipTool(PloneBaseTool, BaseTool):
 
         memberinfo = { 'fullname'    : member.getProperty('fullname'),
                        'description' : member.getProperty('description'),
-                       'location' : member.getProperty('location'),
-                       'language' : member.getProperty('language'),
-                       'home_page' : member.getProperty('home_page'),
+                       'location'    : member.getProperty('location'),
+                       'language'    : member.getProperty('language'),
+                       'home_page'   : member.getProperty('home_page'),
+                       'username'    : member.getUserName(),
                      }
 
         return memberinfo
@@ -105,7 +109,7 @@ class MembershipTool(PloneBaseTool, BaseTool):
         if type(portrait) == type(''):
             portrait = None
         if portrait is not None:
-            if verifyPermission and not _checkPermission(View, portrait):
+            if verifyPermission and not _checkPermission('View', portrait):
                 # Don't return the portrait if the user can't get to it
                 portrait = None
         if portrait is None:
@@ -114,7 +118,7 @@ class MembershipTool(PloneBaseTool, BaseTool):
 
         return portrait
 
-    security.declareProtected(SetOwnProperties, 'deletePersonalPortrait')
+    security.declareProtected(SetOwnProperties, 'deletePersonalPortrait') 
     def deletePersonalPortrait(self, member_id = None):
         """
         deletes the Portrait of member_id
@@ -174,16 +178,11 @@ class MembershipTool(PloneBaseTool, BaseTool):
             member_id = self.getAuthenticatedMember().getId()
 
         if portrait and portrait.filename:
-            portrait = Image(id=member_id, file=portrait, title='')
+            scaled, mimetype = scale_image(portrait)
+            portrait = Image(id=member_id, file=scaled, title='')
             membertool   = getToolByName(self, 'portal_memberdata')
             membertool._setPortrait(portrait, member_id)
 
-
-##     security.declarePrivate('wrapUser')
-##     def wrapUser(self, u):
-##         self.createMemberarea(u.getId())
-##         return BaseTool.wrapUser(self, u)
-
     security.declarePublic('createMemberarea')
     def createMemberarea(self, member_id=None, minimal=1):
         """
@@ -230,8 +229,6 @@ class MembershipTool(PloneBaseTool, BaseTool):
 
         ## translate the default content
 
-        # get some translation interfaces
-
         translation_service = getToolByName(self, 'translation_service', _marker)
         if translation_service is _marker:
             # test environ, some other aberent sitch
@@ -241,7 +238,7 @@ class MembershipTool(PloneBaseTool, BaseTool):
         encode = translation_service.encode
 
         # convert the member_id to unicode type
-        umember_id = translation_service.asunicodetype(member_id, errors='replace')
+        umember_id = translation_service.asunicodetype(user.getUserName(), errors='replace')
 
         member_folder_title = utranslate(
             'plone', 'title_member_folder',
@@ -484,7 +481,6 @@ class MembershipTool(PloneBaseTool, BaseTool):
     security.declareProtected(SetOwnPassword, 'testCurrentPassword')
     def testCurrentPassword(self, password):
         """ test to see if password is current """
-        portal=getToolByName(self, 'portal_url').getPortalObject()
         REQUEST=getattr(self, 'REQUEST', {})
         userid=self.getAuthenticatedMember().getUserId()
         acl_users = self._findUsersAclHome(userid)
@@ -570,8 +566,40 @@ class MembershipTool(PloneBaseTool, BaseTool):
             login_time = member.getProperty('login_time', '2000/01/01')
             if  str(login_time) == '2000/01/01':
                 login_time = self.ZopeTime()
-            member.setProperties(login_time=login_time,
-                                 last_login_time=self.ZopeTime())
+            member.setProperties(login_time=self.ZopeTime(),
+                                 last_login_time=login_time)
+
+    security.declareProtected(ManagePortal, 'getBadMembers')
+    def getBadMembers(self):
+        """Will search for members with bad images in the portal_memberdata
+        delete their portraits and return their member ids"""
+        memberdata = getToolByName(self, 'portal_memberdata')
+        portraits = getattr(memberdata, 'portraits', None)
+        if portraits is None:
+            return []
+        bad_member_ids = []
+        import transaction
+        TXN_THRESHOLD = 50
+        counter = 1
+        for member_id in tuple(portraits.objectIds()):
+            portrait = portraits[member_id]
+            portrait_data = str(portrait.data)
+            if portrait_data == '':
+                continue
+            try:
+                img = PIL.Image.open(StringIO(portrait_data))
+            except ConflictError:
+                pass
+            except:
+                # Anything else we have a bad bad image and we destroy it
+                # and ask questions later.
+                portraits._delObject(member_id)
+                bad_member_ids.append(member_id)
+            if not counter%TXN_THRESHOLD:
+                transaction.savepoint(optimistic=True)
+            counter = counter + 1
+
+        return bad_member_ids
 
 MembershipTool.__doc__ = BaseTool.__doc__
 
