@@ -1,7 +1,7 @@
 from Products.CMFPlone import MigrationTool
 
 def executeMigrations():
-    import v1, v2, v2_1
+    import v1, v2, v2_1, v2_5
 
 def null(portal):
     """ This is a null migration, use it when nothing happens """
@@ -152,3 +152,44 @@ def registerMigrations():
     MigrationTool.registerUpgradePath('2.1.3-rc1',
                                       '2.1.3',
                                       null)
+
+    MigrationTool.registerUpgradePath('2.1.3',
+                                      '2.5-alpha1',
+                                      v2_5.alphas.two5_alpha1)
+
+    MigrationTool.registerUpgradePath('2.5-alpha1',
+                                      '2.5-alpha2',
+                                      v2_5.alphas.alpha1_alpha2)
+
+    MigrationTool.registerUpgradePath('2.5-alpha2',
+                                      '2.5-beta1',
+                                      v2_5.betas.alpha2_beta1)
+
+    MigrationTool.registerUpgradePath('2.5-beta1',
+                                      '2.5-beta2',
+                                      v2_5.betas.beta1_beta2)
+
+    MigrationTool.registerUpgradePath('2.5-beta2',
+                                      '2.5-rc1',
+                                      v2_5.rcs.beta2_rc1)
+
+    MigrationTool.registerUpgradePath('2.5-rc1',
+                                      '2.5-rc2',
+                                      null)
+
+    MigrationTool.registerUpgradePath('2.5-rc2',
+                                      '2.5-rc3',
+                                      null)
+
+    MigrationTool.registerUpgradePath('2.5-rc3',
+                                      '2.5',
+                                      null)
+
+    MigrationTool.registerUpgradePath('2.5',
+                                      '2.5.1-rc1',
+                                      v2_5.final_two51.final_two51)
+
+    MigrationTool.registerUpgradePath('2.5.1-rc1',
+                                      '2.5.1',
+                                      null)
+
