@@ -17,18 +17,16 @@ from cStringIO import StringIO
 from Acquisition import aq_base
 
 from Products.StandardCacheManagers import AcceleratedHTTPCacheManager, RAMCacheManager
-from Products.CMFCore.TypesTool import ContentFactoryMetadata, FactoryTypeInformation
 
 from Products.CMFDefault.Document import addDocument
 from Globals import package_home
 from Products.CMFPlone import cmfplone_globals
-from Products.CMFQuickInstallerTool import QuickInstallerTool, AlreadyInstalled
 from Products.CMFPlone.setup.ConfigurationMethods import addSiteProperties
 from Products.CMFPlone.migrations.migration_util import safeEditProperty
 from Products.CMFPlone import ToolNames, transaction
 
 from Products.CMFCore import CachingPolicyManager
-from Products.CMFCore.CMFCorePermissions import ListFolderContents, SetOwnProperties, SetOwnPassword
+from Products.CMFCore.permissions import ListFolderContents, SetOwnProperties, SetOwnPassword
 from Products.CMFCore.utils import getToolByName
 from Products.CMFCore.TypesTool import FactoryTypeInformation
 from ZODB.POSException import ConflictError
@@ -77,7 +75,6 @@ def make_plone(portal):
     addDocumentActions(portal)
     addActionIcons(portal)
     addCacheAccelerators(portal)
-    #XXX TODO:migrate to add simple workflow
     # change the action in portal_types for viewing a folder
     if 'portal_interface' not in portal.objectIds():
         manage_addTool=portal.manage_addProduct['CMFPlone'].manage_addTool
@@ -131,7 +128,7 @@ def addCatalogLexicon(portal):
         catalog.manage_addProduct[ 'ZCTextIndex' ].manage_addLexicon(
             'plone_lexicon',
             elements=[
-            largs(group= 'Case Normalizer' , name= 'Case Normalizer' ),
+            largs(group= 'Case Normalizer' , name= 'Unicode Case Normalizer' ),
             largs(group= 'Stop Words', name= " Don't remove stop words" ),
             largs(group= 'Word Splitter' , name= "Unicode Whitespace splitter" ),
             ]
@@ -176,23 +173,6 @@ def extendMemberdata(portal):
 def addDefaultPloneSkins(portal):
     pass
 
-# XXX I assume these can be removed, since they no longer ship with Plone.
-#
-#    from Products.CMFPlone.Portal import PloneGenerator
-#    pg=PloneGenerator()
-#    sk_tool=getToolByName(portal, 'portal_skins')
-#
-#    setup_skins=pg.setupSecondarySkin
-#    setup_skins(sk_tool, 'Plone Core',          'plone_styles/core')
-#    setup_skins(sk_tool, 'Plone Corporate',     'plone_styles/corporate')
-#    setup_skins(sk_tool, 'Plone Autumn',        'plone_styles/autumn')
-#    setup_skins(sk_tool, 'Plone Core Inverted', 'plone_styles/core_inverted')
-#    setup_skins(sk_tool, 'Plone Greensleeves',  'plone_styles/greensleeves')
-#    setup_skins(sk_tool, 'Plone Kitty',         'plone_styles/kitty')
-#    setup_skins(sk_tool, 'Plone Mozilla New',   'plone_styles/mozilla_new')
-#    setup_skins(sk_tool, 'Plone Prime',         'plone_styles/prime')
-#    setup_skins(sk_tool, 'Plone Zed',           'plone_styles/zed')
-
 def setupDefaultEditor(portal):
     pass
 
@@ -204,7 +184,7 @@ def addGroupUserFolder(portal):
         NOTE: In the Install routine for GRUF it does a subtransaction commit()
         so that you can manipulate the acl_users folders.
     """
-    transaction.commit(1)
+    transaction.savepoint(optimistic=True)
     out=[]
     out.append('Adding GroupUserFolder to portal')
     qi=getToolByName(portal, 'portal_quickinstaller')
@@ -294,26 +274,10 @@ def addCacheAccelerators(portal):
     if 'caching_policy_manager' not in portal.objectIds():
         CachingPolicyManager.manage_addCachingPolicyManager(portal)
 
-def setupHelpSection(portal):
-    # create and populate the 'plone_help' folder in the root of the plone
-    # the contents are STX files in CMFPlone/docs
-    if 'plone_help' not in portal.objectIds():
-        portal.invokeFactory(type_name='Folder', id='plone_help')
-        plone_help=portal.plone_help
-        docs_path=os.path.join(package_home(cmfplone_globals), 'help')
-        for filename in os.listdir(docs_path):
-            _path=os.path.join(docs_path, filename)
-            if not os.path.isdir(_path):
-                doc=open(_path, 'r')
-                addDocument(plone_help, filename, filename, '',
-                            'structured-text', doc.read())
-                getattr(plone_help,filename)._setPortalTypeName('Document')
-
 def setupCalendar(portal):
     """ Copied directly from CMFCalendar/Extensions/Install.py """
     self=portal
     from Products.CMFCalendar import Event
-    from Products.CMFCore.TypesTool import ContentFactoryMetadata
 
     out = StringIO()
     typestool = getToolByName(self, 'portal_types')
@@ -362,7 +326,7 @@ def setupCalendar(portal):
     # and configure it in the types tool if it doesn't already exist
     for t in Event.factory_type_information:
         if t['id'] not in typestool.objectIds():
-            cfm = apply(ContentFactoryMetadata, (), t)
+            cfm = apply(FactoryTypeInformation, (), t)
             typestool._setObject(t['id'], cfm)
             out.write('Registered with the types tool\n')
         else:
@@ -393,8 +357,8 @@ def setupCalendar(portal):
 
 
 def addActionIcons(portal):
-    """ After installing QuickInstaller.  We must commit(1) a subtrnx
-        so that we will be able to addActionIcons() to the tool
+    """ After installing QuickInstaller.  We must savepoint(optimistic=True) a
+        subtrnx so that we will be able to addActionIcons() to the tool
     """
 
     ai=getToolByName(portal, 'portal_actionicons')
