@@ -2,13 +2,13 @@ from alphas import reindexCatalog, indexMembersFolder, indexNewsFolder, \
                     indexEventsFolder, addIs_FolderishMetadata
 from betas import fixContentActionConditions
 from Products.CMFCore.utils import getToolByName
-from Products.CMFCore import CMFCorePermissions
+from Products.CMFCore.permissions import View
 from Products.CMFPlone.utils import _createObjectByType
+from Products.CMFPlone.utils import _unrestricted_rename
 from Products.CMFPlone.migrations.migration_util import cleanupSkinPath
-from Acquisition import aq_base, aq_inner, aq_parent
-from Products.CMFPlone import transaction
+from Acquisition import aq_base
 from Products.GroupUserFolder.GroupsToolPermissions import ViewGroups
-
+import transaction
 
 def rc1_rc2(portal):
     """2.1-rc1 -> 2.1-rc2
@@ -155,7 +155,7 @@ def alterRSSActionTitle(portal, out):
                   'name'      : 'RSS feed of this listing',
                   'action'    : 'string:$object_url/RSS',
                   'condition' : 'python:portal.portal_syndication.isSyndicationAllowed(object)',
-                  'permission': CMFCorePermissions.View,
+                  'permission': View,
                   'category': 'document_actions',
                 }
     exists = False
@@ -273,23 +273,23 @@ def moveDefaultTopicsToPortalRoot(portal, out):
                     folder.manage_delObjects([topic['old_id']])
                     out.append(
                               "Moved %s topic to portal root"%topic['new_id'])
-                    transaction.commit(1)
+                    transaction.savepoint(optimistic=True)
                     if not folder.objectIds():
                         # Delete empty folders
                         portal.manage_delObjects([topic['new_id']])
                         out.append("Deleted empty %s folder"%topic['new_id'])
                     else:
                         # Rename non-empty folders
-                        portal.manage_renameObjects([topic['new_id']],
-                                                     ['old_'+topic['new_id']])
+                        _unrestricted_rename(portal, topic['new_id'],
+                                                     'old_'+topic['new_id'])
                         out.append("Moved old %s folder to old_%s"%(topic['new_id'],topic['new_id']))
                         old_fold = getattr(portal, 'old_'+topic['new_id'])
                         # Exclude the renamed folder from navigation
                         # old_fold.setExcludeFromNav(True)
                         old_fold.setTitle('Old ' + old_fold.Title())
                         old_fold.reindexObject()
-                    portal.manage_renameObjects([topic['old_id']],
-                                                        [topic['new_id']])
+                    _unrestricted_rename(portal, topic['old_id'],
+                                                 topic['new_id'])
                     portal.moveObject(topic['new_id'], old_pos)
                     putils = getattr(portal, 'plone_utils', None)
                     if putils is not None:
