@@ -7,19 +7,20 @@
 ##parameters=addname=None, groupname=None
 ##title=Edit user
 ##
-from Products.PythonScripts.standard import url_quote
+
+from Products.CMFPlone import PloneMessageFactory as _
 
 REQUEST=context.REQUEST
-msg = 'No change has been done.'
+msg = _(u'No changes done.')
 
 if addname:
     context.portal_groups.addGroup(addname,(),())
     group=context.portal_groups.getGroupById(addname)
-    msg = context.translate("Group ${name} has been added.",
-                            {'name': addname})
+    msg = _(u'Group ${name} has been added.',
+            mapping={u'name' : addname})
 else:
     group=context.portal_groups.getGroupById(groupname)
-    msg = 'Changes saved.'
+    msg = _(u'Changes saved.')
 
 processed={}
 for id, property in context.portal_groupdata.propertyItems():
@@ -29,8 +30,6 @@ if group:
     # for what reason ever, the very first group created does not exist
     group.setGroupProperties(processed)
 
-url='%s?%s=%s' % (context.prefs_groups_overview.absolute_url(),
-    url_quote('portal_status_message'),
-    url_quote(msg))
+context.plone_utils.addPortalMessage(msg)
 
-return REQUEST.RESPONSE.redirect(url)
+return REQUEST.RESPONSE.redirect(context.prefs_groups_overview.absolute_url())
