@@ -6,20 +6,21 @@ import os, sys
 if __name__ == '__main__':
     execfile(os.path.join(sys.path[0], 'framework.py'))
 
-from Testing import ZopeTestCase
 from Products.CMFPlone.tests import PloneTestCase
 from Products.CMFPlone.tests import dummy
-from DateTime import DateTime
+
 from Products.CMFCore.utils import getToolByName
 from Acquisition import Implicit
 
 default_user = PloneTestCase.default_user
-
+portal_name = PloneTestCase.portal_name
 
 class DummyTitle(Implicit):
     def Title(self):
         # Should just return 'portal_catalog'
         tool = getToolByName(self, 'portal_catalog')
+        # Use implicit acquisition even, the horror
+        tool = self.portal_catalog
         return tool.getId()
     def getId(self):
         return 'foobar'
@@ -34,24 +35,16 @@ class TestPloneTool(PloneTestCase.PloneTestCase):
         # Any RFC 822 email address allowed, but address list must fail
         val = self.utils.validateSingleEmailAddress
         validInputs = (
-            #'user',
-            #'user@foo',
             'user@example.org',
             'user@host.example.org',
             'm@t.nu',
             'USER@EXAMPLE.ORG',
             'USER@HOST.EXAMPLE.ORG',
             'USER@hoST.Example.Org',
-
-            ## Some trickier ones, from RFC 822
-            #'"A Name" user @ example',
-            #'"A Name" user\n @ example',
-            #'nn@[1.2.3.4]'
         )
         invalidInputs = (
             'user@example.org, user2@example.org',   # only single address allowed
             'user@example.org,user2@example.org',
-            #'user@example.org;user2@example.org',
             'user@example.org\n\nfoo', # double new lines
             'user@example.org\n\rfoo',
             'user@example.org\r\nfoo',
@@ -67,13 +60,12 @@ class TestPloneTool(PloneTestCase.PloneTestCase):
             'Subject: Spam me plenty\n'
             'Spam Spam Spam\n'
             'I hate spam',
-            
         )
         for address in validInputs:
             self.failUnless(val(address), '%s should validate' % address)
         for address in invalidInputs:
             self.failIf(val(address), '%s should fail' % address)
-    
+
     def testvalidateEmailAddresses(self):
         # Any RFC 822 email address allowed and address list allowed
         val = self.utils.validateEmailAddresses
@@ -101,7 +93,7 @@ class TestPloneTool(PloneTestCase.PloneTestCase):
             self.failIf(val(address), '%s should fail' % address)
 
     def testEditFormatMetadataOfFile(self):
-        # Test fix for http://plone.org/collector/1323
+        # Test fix for http://dev.plone.org/plone/ticket/1323
         # Fixed in CMFDefault.File, not Plone.
         self.folder.invokeFactory('File', id='file')
         self.folder.file.edit(file=dummy.File('foo.zip'))
@@ -113,7 +105,7 @@ class TestPloneTool(PloneTestCase.PloneTestCase):
         self.assertEqual(self.folder.file.getFile().content_type, 'image/gif')
 
     def testEditFormatMetadataOfImage(self):
-        # Test fix for http://plone.org/collector/1323
+        # Test fix for http://dev.plone.org/plone/ticket/1323
         # Fixed in CMFDefault.Image, not Plone.
         self.folder.invokeFactory('Image', id='image')
         self.folder.image.edit(file=dummy.Image('foo.zip'))
@@ -139,10 +131,11 @@ class TestPloneTool(PloneTestCase.PloneTestCase):
         # Punctuation and spaces are trimmed, multiples reduced to 1
         self.assertEqual(self.utils.normalizeString(" a string    "),
                          'a-string')
-        self.assertEqual(self.utils.normalizeString(">here's another!"),
-                         'here-s-another')
-        self.assertEqual(self.utils.normalizeString("one with !@#$!@#$ stuff in the middle"),
-                         'one-with-stuff-in-the-middle')
+        self.assertEqual(self.utils.normalizeString(">here is another!"),
+                         'here-is-another')
+        self.assertEqual(
+            self.utils.normalizeString("one with !@#$!@#$ stuff in the middle"),
+            'one-with-stuff-in-the-middle')
 
     def testNormalizeStringFileExtensions(self):
         # If there is something that looks like a file extensions
@@ -153,7 +146,8 @@ class TestPloneTool(PloneTestCase.PloneTestCase):
                          'this-is-also-a-file.html')
 
     def testNormalizeStringAccents(self):
-        # European accented chars will be transliterated to rough ASCII equivalents
+        # European accented chars will be transliterated to rough
+        # ASCII equivalents
         input = u"Eksempel \xe6\xf8\xe5 norsk \xc6\xd8\xc5"
         self.assertEqual(self.utils.normalizeString(input),
                          'eksempel-eoa-norsk-eoa')
@@ -166,20 +160,28 @@ class TestPloneTool(PloneTestCase.PloneTestCase):
 
     def testNormalizeGreek(self):
         # Greek letters (not supported by UnicodeData)
-        input = u'\u039d\u03af\u03ba\u03bf\u03c2 \u03a4\u03b6\u03ac\u03bd\u03bf\u03c2'
+        input = (u'\u039d\u03af\u03ba\u03bf\u03c2 '
+                 u'\u03a4\u03b6\u03ac\u03bd\u03bf\u03c2')
         self.assertEqual(self.utils.normalizeString(input), 'nikos-tzanos')
- 
+
     def testNormalizeGreekUTF8(self):
         # Greek letters (not supported by UnicodeData)
-        input = u'\u039d\u03af\u03ba\u03bf\u03c2 \u03a4\u03b6\u03ac\u03bd\u03bf\u03c2'.encode('utf-8')
+        input = (u'\u039d\u03af\u03ba\u03bf\u03c2 '
+                 u'\u03a4\u03b6\u03ac\u03bd\u03bf\u03c2').encode('utf-8')
         self.assertEqual(self.utils.normalizeString(input), 'nikos-tzanos')
- 
+
     def testNormalizeStringHex(self):
         # Everything that can't be transliterated will be hex'd
-        self.assertEqual(self.utils.normalizeString(u"\u9ad8\u8054\u5408 Chinese"),
-                         '9ad880545408-chinese')
-        self.assertEqual(self.utils.normalizeString(u"\uc774\ubbf8\uc9f1 Korean"),
-                         'c774bbf8c9f1-korean')
+        self.assertEqual(
+            self.utils.normalizeString(u"\u9ad8\u8054\u5408 Chinese"),
+            '9ad880545408-chinese')
+        self.assertEqual(
+            self.utils.normalizeString(u"\uc774\ubbf8\uc9f1 Korean"),
+            'c774bbf8c9f1-korean')
+
+    def testNormalizeStringIgnoredCharacters(self):
+        # Some characters should be ignored
+        self.assertEqual(self.utils.normalizeString("test'test"), 'testtest')
 
     def testNormalizeStringObject(self):
         # Objects should be converted to strings using repr()
@@ -187,6 +189,34 @@ class TestPloneTool(PloneTestCase.PloneTestCase):
         self.assertEqual(self.utils.normalizeString(True), 'true')
         self.assertEqual(self.utils.normalizeString(False), 'false')
 
+    def testNormalizeStringDangerousCharsInExtension(self):
+        # Punctuation and spacing is removed and replaced by '-'
+        self.assertEqual(self.utils.normalizeString("A String.a#b"),
+                         'a-string-a-b')
+
+    def testNormalizeStringRelaxedKeepsUppercaseAndSpaces(self):
+        # Punctuation and spacing is removed and replaced by '-'
+        self.assertEqual(self.utils.normalizeString("Capital Letters and Spaces", relaxed=True),
+                         'Capital Letters and Spaces')
+
+    def testNormalizeStringRelaxedStripsDangerousChars(self):
+        # Punctuation and spacing is removed and replaced by '-'
+        self.assertEqual(self.utils.normalizeString("A ?String&/\\foo.x#x", relaxed=True),
+                         'A -String-foo.x-x')
+
+    def testNormalizeStringRelaxedKeepsOtherSymbols(self):
+        # Punctuation and spacing is removed and replaced by '-'
+        self.assertEqual(self.utils.normalizeString("A ?String&/\\.foo_!$#xx", relaxed=True),
+                         'A -String-.foo_!$-xx')
+
+    def testTypesToList(self):
+        # Make sure typesToList() returns the expected types
+        wl = self.utils.typesToList()
+        self.failUnless('Folder' in wl)
+        self.failUnless('Large Plone Folder' in wl)
+        self.failUnless('Topic' in wl)
+        self.failIf('ATReferenceCriterion' in wl)
+
 
 class TestOwnershipStuff(PloneTestCase.PloneTestCase):
 
@@ -212,11 +242,13 @@ class TestOwnershipStuff(PloneTestCase.PloneTestCase):
     def testChangeOwnershipOf(self):
         # Should take ownership
         self.assertEqual(self.folder1.getOwnerTuple()[1], default_user)
-        self.assertList(self.folder1.get_local_roles_for_userid(default_user), ['Owner'])
+        self.assertList(self.folder1.get_local_roles_for_userid(default_user),
+                        ['Owner'])
 
         self.utils.changeOwnershipOf(self.folder1, 'new_owner')
         self.assertEqual(self.folder1.getOwnerTuple()[1], 'new_owner')
-        self.assertList(self.folder1.get_local_roles_for_userid('new_owner'), ['Owner'])
+        self.assertList(self.folder1.get_local_roles_for_userid('new_owner'),
+                        ['Owner'])
 
         # Initial creator no longer has Owner role.
         self.assertList(self.folder1.get_local_roles_for_userid(default_user), [])
@@ -224,23 +256,28 @@ class TestOwnershipStuff(PloneTestCase.PloneTestCase):
     def testChangeOwnershipOfKeepsOtherRoles(self):
         # Should preserve roles other than Owner
         self.folder1.manage_addLocalRoles('new_owner', ('Reviewer',))
-        self.assertList(self.folder1.get_local_roles_for_userid('new_owner'), ['Reviewer'])
+        self.assertList(self.folder1.get_local_roles_for_userid('new_owner'),
+                        ['Reviewer'])
         self.utils.changeOwnershipOf(self.folder1, 'new_owner')
         self.assertEqual(self.folder1.getOwnerTuple()[1], 'new_owner')
-        self.assertList(self.folder1.get_local_roles_for_userid('new_owner'), ['Owner', 'Reviewer'])
+        self.assertList(self.folder1.get_local_roles_for_userid('new_owner'),
+                        ['Owner', 'Reviewer'])
         self.assertList(self.folder1.get_local_roles_for_userid(default_user), [])
 
     def testChangeOwnershipOfRecursive(self):
         # Should take ownership of subobjects as well
         self.utils.changeOwnershipOf(self.folder1, 'new_owner', recursive=1)
         self.assertEqual(self.folder1.getOwnerTuple()[1], 'new_owner')
-        self.assertList(self.folder1.get_local_roles_for_userid('new_owner'), ['Owner'])
+        self.assertList(self.folder1.get_local_roles_for_userid('new_owner'),
+                        ['Owner'])
         self.assertList(self.folder1.get_local_roles_for_userid(default_user), [])
         self.assertEqual(self.folder2.getOwnerTuple()[1], 'new_owner')
-        self.assertList(self.folder2.get_local_roles_for_userid('new_owner'), ['Owner'])
+        self.assertList(self.folder2.get_local_roles_for_userid('new_owner'),
+                        ['Owner'])
         self.assertList(self.folder2.get_local_roles_for_userid(default_user), [])
         self.assertEqual(self.folder3.getOwnerTuple()[1], 'new_owner')
-        self.assertList(self.folder3.get_local_roles_for_userid('new_owner'), ['Owner'])
+        self.assertList(self.folder3.get_local_roles_for_userid('new_owner'),
+                        ['Owner'])
         self.assertList(self.folder3.get_local_roles_for_userid(default_user), [])
 
     def testGetOwnerName(self):
@@ -261,7 +298,7 @@ class TestOwnershipStuff(PloneTestCase.PloneTestCase):
         self.assertList(filtered_roles[1], ['Reviewer'])
 
     def testGetInheritedLocalRolesMultiLevel(self):
-        # Test for http://members.plone.org/collector/3901
+        # Test for http://dev.plone.org/plone/ticket/3901
         # make sure local roles are picked up from all folders in tree.
         gILR = self.utils.getInheritedLocalRoles
         self.folder1.manage_addLocalRoles('new_owner', ('Reviewer',))
@@ -395,7 +432,7 @@ class TestEditMetadata(PloneTestCase.PloneTestCase):
     def testTuplifySubject_1(self):
         self.utils.editMetadata(self.doc, subject=['Foo', 'Bar', 'Baz'])
         self.assertEqual(self.doc.Subject(), ('Foo', 'Bar', 'Baz'))
-        
+
     def testTuplifySubject_2(self):
         self.utils.editMetadata(self.doc, subject=['Foo', '', 'Bar', 'Baz'])
         # Note that empty entries are filtered
@@ -403,13 +440,13 @@ class TestEditMetadata(PloneTestCase.PloneTestCase):
 
     def DISABLED_testTuplifySubject_3(self):
         self.utils.editMetadata(self.doc, subject='Foo, Bar, Baz')
-        # XXX: Wishful thinking
+        # TODO: Wishful thinking
         self.assertEqual(self.doc.Subject(), ('Foo', 'Bar', 'Baz'))
-        
+
     def testTuplifyContributors_1(self):
         self.utils.editMetadata(self.doc, contributors=['Foo', 'Bar', 'Baz'])
         self.assertEqual(self.doc.Contributors(), ('Foo', 'Bar', 'Baz'))
-        
+
     def testTuplifyContributors_2(self):
         self.utils.editMetadata(self.doc, contributors=['Foo', '', 'Bar', 'Baz'])
         # Note that empty entries are filtered
@@ -417,9 +454,9 @@ class TestEditMetadata(PloneTestCase.PloneTestCase):
 
     def DISABLED_testTuplifyContributors_3(self):
         self.utils.editMetadata(self.doc, contributors='Foo; Bar; Baz')
-        # XXX: Wishful thinking
+        # TODO: Wishful thinking
         self.assertEqual(self.doc.Contributors(), ('Foo', 'Bar', 'Baz'))
-        
+
 
 class TestEditMetadataIndependence(PloneTestCase.PloneTestCase):
 
@@ -427,7 +464,7 @@ class TestEditMetadataIndependence(PloneTestCase.PloneTestCase):
         self.utils = self.portal.plone_utils
         self.folder.invokeFactory('Document', id='doc')
         self.doc = self.folder.doc
-        self.utils.editMetadata(self.doc, 
+        self.utils.editMetadata(self.doc,
                                 title='Foo',
                                 subject=('Bar',),
                                 description='Baz',
@@ -493,7 +530,8 @@ class TestEditMetadataIndependence(PloneTestCase.PloneTestCase):
 
 
 class TestFormulatorFields(PloneTestCase.PloneTestCase):
-    '''This feature should probably go away entirely.'''
+    """This feature should probably go away entirely.
+    """
 
     def afterSetUp(self):
         self.utils = self.portal.plone_utils
@@ -523,229 +561,10 @@ class TestFormulatorFields(PloneTestCase.PloneTestCase):
     def testLanguageField(self):
         self.setField('language', 'de')
         self.utils.editMetadata(self.doc)
-        # XXX: Note that language, format, and rights do not 
+        # TODO: Note that language, format, and rights do not 
         #      receive the Formulator treatment.
         self.assertEqual(self.doc.Language(), '')
 
-
-class TestNavTree(PloneTestCase.PloneTestCase):
-    '''Tests for the new navigation tree and sitemap'''
-
-    def afterSetUp(self):
-        self.utils = self.portal.plone_utils
-        self.populateSite()
-
-    def populateSite(self):
-        self.setRoles(['Manager'])
-        self.portal.invokeFactory('Document', 'doc1')
-        self.portal.invokeFactory('Document', 'doc2')
-        self.portal.invokeFactory('Document', 'doc3')
-        self.portal.invokeFactory('Folder', 'folder1')
-        folder1 = getattr(self.portal, 'folder1')
-        folder1.invokeFactory('Document', 'doc11')
-        folder1.invokeFactory('Document', 'doc12')
-        folder1.invokeFactory('Document', 'doc13')
-        self.portal.invokeFactory('Folder', 'folder2')
-        folder2 = getattr(self.portal, 'folder2')
-        folder2.invokeFactory('Document', 'doc21')
-        folder2.invokeFactory('Document', 'doc22')
-        folder2.invokeFactory('Document', 'doc23')
-        folder2.invokeFactory('File', 'file21')
-        self.setRoles(['Member'])
-
-    def testTypesToList(self):
-        # Make sure typesToList() returns the expected types
-        wl = self.utils.typesToList()
-        self.failUnless('Folder' in wl)
-        self.failUnless('Large Plone Folder' in wl)
-        self.failUnless('Topic' in wl)
-        self.failIf('ATReferenceCriterion' in wl)
-
-    def testCreateNavTree(self):
-        # See if we can create one at all
-        tree = self.utils.createNavTree(self.portal)
-        self.failUnless(tree)
-        self.failUnless(tree.has_key('children'))
-
-    def testCreateNavTreeCurrentItem(self):
-        # With the context set to folder2 it should return a dict with
-        # currentItem set to True
-        tree = self.utils.createNavTree(self.portal.folder2)
-        self.failUnless(tree)
-        self.assertEqual(tree['children'][-1]['currentItem'], True)
-
-    def testCreateNavTreeRespectsTypesWithViewAction(self):
-        # With a File or Image as current action it should return a
-        # currentItem which has '/view' appended to the url
-        tree = self.utils.createNavTree(self.portal.folder2.file21)
-        self.failUnless(tree)
-        # Fail if 'view' is used for parent folder; it should only be on the File
-        self.failIf(tree['children'][-1]['absolute_url'][-5:]=='/view')
-        # Verify we have the correct object and it is the current item
-        self.assertEqual(tree['children'][-1]['children'][-1]['currentItem'],True)
-        self.assertEqual(tree['children'][-1]['children'][-1]['path'].split('/')[-1],'file21')
-        # Verify that we have '/view'
-        self.assertEqual(tree['children'][-1]['children'][-1]['absolute_url'][-5:],'/view')
-
-    def testNavTreeExcludesItemsWithExcludeProperty(self):
-        # Make sure that items witht he exclude_from_nav property set get
-        # no_display set to True
-        self.portal.folder2.setExcludeFromNav(True)
-        self.portal.folder2.reindexObject()
-        tree = self.utils.createNavTree(self.portal.folder2.file21)
-        self.failUnless(tree)
-        self.assertEqual(tree['children'][-1]['no_display'],True)
-        # Shouldn't exlude anything else
-        self.assertEqual(tree['children'][0]['no_display'],False)
-
-    def testNavTreeExcludesItemsInIdsNotToList(self):
-        # Make sure that items whose ids are in the idsNotToList navTree
-        # property get no_display set to True
-        ntp=self.portal.portal_properties.navtree_properties
-        ntp.manage_changeProperties(idsNotToList=['folder2'])
-        tree = self.utils.createNavTree(self.portal.folder2.file21)
-        self.failUnless(tree)
-        self.assertEqual(tree['children'][-1]['no_display'],True)
-        # Shouldn't exlude anything else
-        self.assertEqual(tree['children'][0]['no_display'],False)
-
-    def testNavTreeExcludesDefaultPage(self):
-        # Make sure that items which are the default page are excluded
-        self.portal.folder2.setDefaultPage('doc21')
-        tree = self.utils.createNavTree(self.portal.folder2.file21)
-        self.failUnless(tree)
-        # Ensure that our 'doc21' default page is not in the tree.
-        self.assertEqual([c for c in tree['children'][-1]['children']
-                                            if c['path'][-5:]=='doc21'],[])
-
-    def testNavTreeMarksParentMetaTypesNotToQuery(self):
-        # Make sure that items whose ids are in the idsNotToList navTree
-        # property get no_display set to True
-        tree = self.utils.createNavTree(self.portal.folder2.file21)
-        self.assertEqual(tree['children'][-1]['show_children'],True)
-        ntp=self.portal.portal_properties.navtree_properties
-        ntp.manage_changeProperties(parentMetaTypesNotToQuery=['Folder'])
-        tree = self.utils.createNavTree(self.portal.folder2.file21)
-        self.assertEqual(tree['children'][-1]['show_children'],False)
-
-    def testNonStructuralFolderHidesChildren(self):
-        # Make sure NonStructuralFolders act as if parentMetaTypesNotToQuery
-        # is set.
-        f = dummy.NonStructuralFolder('ns_folder')
-        self.folder._setObject('ns_folder', f)
-        self.portal.portal_catalog.reindexObject(self.folder.ns_folder)
-        self.portal.portal_catalog.reindexObject(self.folder)
-        tree = self.utils.createNavTree(self.folder.ns_folder)
-        self.assertEqual(tree['children'][0]['children'][0]['children'][0]['path'],
-                                '/portal/Members/test_user_1_/ns_folder')
-        self.assertEqual(tree['children'][0]['children'][0]['children'][0]['show_children'],False)
-
-    def testCreateSitemap(self):
-        # Internally createSitemap is the same as createNavTree
-        tree = self.utils.createSitemap(self.portal)
-        self.failUnless(tree)
-
-    def testCustomQuery(self):
-        # Try a custom query script for the navtree that returns only published
-        # objects
-        workflow = self.portal.portal_workflow
-        factory = self.portal.manage_addProduct['PythonScripts']
-        factory.manage_addPythonScript('getCustomNavQuery')
-        script = self.portal.getCustomNavQuery
-        script.ZPythonScript_edit('','return {"review_state":"published"}')
-        self.assertEqual(self.portal.getCustomNavQuery(),{"review_state":"published"})
-        tree = self.utils.createNavTree(self.portal.folder2)
-        self.failUnless(tree)
-        self.failUnless(tree.has_key('children'))
-        #Should only contain current object
-        self.assertEqual(len(tree['children']), 1)
-        #change workflow for folder1
-        workflow.doActionFor(self.portal.folder1, 'publish')
-        self.portal.folder1.reindexObject()
-        tree = self.utils.createNavTree(self.portal.folder2)
-        #Should only contain current object and published folder
-        self.assertEqual(len(tree['children']), 2)
-
-    def testStateFiltering(self):
-        # Test Navtree workflow state filtering
-        workflow = self.portal.portal_workflow
-        ntp=self.portal.portal_properties.navtree_properties
-        ntp.manage_changeProperties(wf_states_to_show=['published'])
-        ntp.manage_changeProperties(enable_wf_state_filtering=True)
-        tree = self.utils.createNavTree(self.portal.folder2)
-        self.failUnless(tree)
-        self.failUnless(tree.has_key('children'))
-        #Should only contain current object
-        self.assertEqual(len(tree['children']), 1)
-        #change workflow for folder1
-        workflow.doActionFor(self.portal.folder1, 'publish')
-        self.portal.folder1.reindexObject()
-        tree = self.utils.createNavTree(self.portal.folder2)
-        #Should only contain current object and published folder
-        self.assertEqual(len(tree['children']), 2)
-
-    def testComplexSitemap(self):
-        # create and test a reasonabley complex sitemap
-        path = lambda x: '/'.join(x.getPhysicalPath())
-        # We do this in a strange order in order to maximally demonstrate the bug
-        folder1 = self.portal.folder1
-        folder1.invokeFactory('Folder','subfolder1')
-        subfolder1 = folder1.subfolder1
-        folder1.invokeFactory('Folder','subfolder2')
-        subfolder2 = folder1.subfolder2
-        subfolder1.invokeFactory('Folder','subfolder11')
-        subfolder11 = subfolder1.subfolder11
-        subfolder1.invokeFactory('Folder','subfolder12')
-        subfolder12 = subfolder1.subfolder12
-        subfolder2.invokeFactory('Folder','subfolder21')
-        subfolder21 = subfolder2.subfolder21
-        folder1.invokeFactory('Folder','subfolder3')
-        subfolder3 = folder1.subfolder3
-        subfolder2.invokeFactory('Folder','subfolder22')
-        subfolder22 = subfolder2.subfolder22
-        subfolder22.invokeFactory('Folder','subfolder221')
-        subfolder221 = subfolder22.subfolder221
-
-        # Increase depth
-        ntp=self.portal.portal_properties.navtree_properties
-        ntp.manage_changeProperties(sitemapDepth=5)
-
-        sitemap = self.utils.createSitemap(self.portal)
-
-        folder1map = sitemap['children'][6]
-        self.assertEqual(len(folder1map['children']), 6)
-        self.assertEqual(folder1map['path'], path(folder1))
-
-        subfolder1map = folder1map['children'][3]
-        self.assertEqual(subfolder1map['path'], path(subfolder1))
-        self.assertEqual(len(subfolder1map['children']), 2)
-
-        subfolder2map = folder1map['children'][4]
-        self.assertEqual(subfolder2map['path'], path(subfolder2))
-        self.assertEqual(len(subfolder2map['children']), 2)
-
-        subfolder3map = folder1map['children'][5]
-        self.assertEqual(subfolder3map['path'], path(subfolder3))
-        self.assertEqual(len(subfolder3map['children']), 0)
-
-        subfolder11map = subfolder1map['children'][0]
-        self.assertEqual(subfolder11map['path'], path(subfolder11))
-        self.assertEqual(len(subfolder11map['children']), 0)
-
-        subfolder21map = subfolder2map['children'][0]
-        self.assertEqual(subfolder21map['path'], path(subfolder21))
-        self.assertEqual(len(subfolder21map['children']), 0)
-
-        subfolder22map = subfolder2map['children'][1]
-        self.assertEqual(subfolder22map['path'], path(subfolder22))
-        self.assertEqual(len(subfolder22map['children']), 1)
-
-        # Why isn't this showing up in the sitemap
-        subfolder221map = subfolder22map['children'][0]
-        self.assertEqual(subfolder221map['path'], path(subfolder221))
-        self.assertEqual(len(subfolder221map['children']), 0)
-
-
 class TestPortalTabs(PloneTestCase.PloneTestCase):
     '''Tests for the portal tabs query'''
 
@@ -770,6 +589,26 @@ class TestPortalTabs(PloneTestCase.PloneTestCase):
         self.failUnless(tabs)
         #Only the folders show up (Members, news, events, folder1, folder2)
         self.assertEqual(len(tabs), 5)
+        # Check if selecting a different category returns the same results
+        tabs = self.utils.createTopLevelTabs(category='notthere')
+        self.assertEqual(len(tabs), 5)
+        # Now register an action in the default category
+        actions={ "portal_tabs" : [
+                        { "category" : "portal_tabs",
+                          "available" : True,
+                          "title"    : "Test tab",
+                          "url"      : "test",
+                          "name"     : "Home",
+                          "visible"  : True,
+                          "allowed"  : True,
+                          "id"       : "test",
+                          "permissions" : ("View",)}]}
+        # The new action should appear in the normal tabs
+        tabs = self.utils.createTopLevelTabs(actions)
+        self.assertEqual(len(tabs), 6)
+        # But it should not appear if we select a different action category
+        tabs = self.utils.createTopLevelTabs(actions,category='notthere')
+        self.assertEqual(len(tabs), 5)
 
     def testTabsRespectFolderOrder(self):
         # See if reordering causes a change in the tab order
@@ -882,7 +721,7 @@ class TestPortalTabs(PloneTestCase.PloneTestCase):
         self.failIf(self.utils.isStructuralFolder(i))
 
     def testIsStructuralFolderWithFolder(self):
-        f = dummy.ATFolder('struct_folder')
+        f = dummy.Folder('struct_folder')
         self.failUnless(self.utils.isStructuralFolder(f))
 
     def testIsStructuralFolderWithNonStructuralFolder(self):
@@ -924,7 +763,8 @@ class TestBreadCrumbs(PloneTestCase.PloneTestCase):
 
 
 class TestIDGenerationMethods(PloneTestCase.PloneTestCase):
-    '''Tests the isIDAutoGenerated method and pretty_title_or_id'''
+    """Tests the isIDAutoGenerated method and pretty_title_or_id
+    """
 
     def afterSetUp(self):
         self.utils = self.portal.plone_utils
@@ -946,11 +786,13 @@ class TestIDGenerationMethods(PloneTestCase.PloneTestCase):
 
     def test_pretty_title_or_id_returns_title(self):
         self.folder.setTitle('My pretty title')
-        self.assertEqual(self.utils.pretty_title_or_id(self.folder), 'My pretty title')
+        self.assertEqual(self.utils.pretty_title_or_id(self.folder),
+                         'My pretty title')
 
     def test_pretty_title_or_id_returns_id(self):
         self.folder.setTitle('')
-        self.assertEqual(self.utils.pretty_title_or_id(self.folder), self.folder.getId())
+        self.assertEqual(self.utils.pretty_title_or_id(self.folder),
+                         self.folder.getId())
 
     def test_pretty_title_or_id_when_autogenerated(self):
         self.setRoles(['Manager','Member'])
@@ -993,8 +835,8 @@ class TestIDGenerationMethods(PloneTestCase.PloneTestCase):
     def test_pretty_title_or_id_on_catalog_brain_autogenerated(self):
         cat = self.portal.portal_catalog
         self.setRoles(['Manager','Member'])
-        self.folder.edit(id='folder.2004-11-09.0123456789', title='',
-                                                            subject='foobar')
+        self.folder.edit(id='folder.2004-11-09.0123456789',
+                         title='', subject='foobar')
         results = cat(Subject='foobar')
         self.assertEqual(len(results), 1)
         self.assertEqual(self.utils.pretty_title_or_id(results[0], 'Marker'),
@@ -1023,6 +865,39 @@ class TestIDGenerationMethods(PloneTestCase.PloneTestCase):
         for k, v in aliases.items():
             self.assertEqual(expectedAliases[k], v)
 
+class TestPortalStatusMessages(PloneTestCase.PloneTestCase):
+    '''Tests the portal status messages methods'''
+
+    def afterSetUp(self):
+        self.utils = self.portal.plone_utils
+
+    # XXX these don't work anymore as the cookie handling needs a real
+    # request/response to take effect
+    def DISABLED_testPortalMessages(self):
+        # make sure there's no stored message
+        self.assertEqual(len(self.utils.showPortalMessages()), 0)
+        # add one message
+        self.utils.addPortalMessage(u'message', type=u'info')
+        msgs = self.utils.showPortalMessages()
+        self.assertEqual(len(msgs), 1)
+        self.assertEqual(msgs[0].message, u'message')
+        self.assertEqual(msgs[0].type, u'info')
+        # make sure messages are removed
+        msgs = self.utils.showPortalMessages()
+        self.assertEqual(len(msgs), 0)
+        # add two messages
+        self.utils.addPortalMessage(u'message1', type=u'info')
+        self.utils.addPortalMessage(u'message2', type=u'warn')
+        msgs = self.utils.showPortalMessages()
+        self.assertEqual(len(msgs), 2)
+        self.assertEqual(msgs[0].message, u'message1')
+        self.assertEqual(msgs[0].type, u'info')
+        self.assertEqual(msgs[1].message, u'message2')
+        self.assertEqual(msgs[1].type, u'warn')
+        # make sure there's no stored message
+        self.assertEqual(len(self.utils.showPortalMessages()), 0)
+
+
 def test_suite():
     from unittest import TestSuite, makeSuite
     suite = TestSuite()
@@ -1031,10 +906,10 @@ def test_suite():
     suite.addTest(makeSuite(TestEditMetadata))
     suite.addTest(makeSuite(TestEditMetadataIndependence))
     suite.addTest(makeSuite(TestFormulatorFields))
-    suite.addTest(makeSuite(TestNavTree))
     suite.addTest(makeSuite(TestPortalTabs))
     suite.addTest(makeSuite(TestBreadCrumbs))
     suite.addTest(makeSuite(TestIDGenerationMethods))
+    suite.addTest(makeSuite(TestPortalStatusMessages))
     return suite
 
 if __name__ == '__main__':
