@@ -6,9 +6,9 @@ import os, sys
 if __name__ == '__main__':
     execfile(os.path.join(sys.path[0], 'framework.py'))
 
-from Testing import ZopeTestCase
-from Products.CMFCore.permissions import AccessInactivePortalContent
 from Products.CMFPlone.tests import PloneTestCase
+
+from Products.CMFCore.permissions import AccessInactivePortalContent
 from Products.CMFPlone.tests import dummy
 
 from Products.PageTemplates.ZopePageTemplate import ZopePageTemplate
@@ -16,6 +16,14 @@ from Acquisition import aq_base
 from DateTime import DateTime
 from tempfile import mkstemp
 
+from Products.StandardCacheManagers.AcceleratedHTTPCacheManager import \
+     AcceleratedHTTPCacheManager
+from Products.StandardCacheManagers.RAMCacheManager import \
+     RAMCacheManager
+from Products.CMFCore.CachingPolicyManager import CachingPolicyManager
+from Products.CMFPlone.UnicodeSplitter import Splitter, CaseNormalizer
+from Products.CMFPlone import setuphandlers
+
 
 class TestPortalCreation(PloneTestCase.PloneTestCase):
 
@@ -31,10 +39,10 @@ class TestPortalCreation(PloneTestCase.PloneTestCase):
         self.catalog = self.portal.portal_catalog
         self.groups = self.portal.portal_groups
         self.factory = self.portal.portal_factory
-        self.cc = self.portal.cookie_authentication
         self.skins = self.portal.portal_skins
         self.transforms = self.portal.portal_transforms
         self.javascripts = self.portal.portal_javascripts
+        self.setup = self.portal.portal_setup
 
     def testPloneSkins(self):
         # Plone skins should have been set up
@@ -53,7 +61,7 @@ class TestPortalCreation(PloneTestCase.PloneTestCase):
         self.portal.manage_main()
 
     def testControlPanelGroups(self):
-        # Test for https://plone.org/collector/2749
+        # Test for http://dev.plone.org/plone/ticket/2749
         # Wake up object, in the case it was deactivated.
         dir(self.cp); dir(self.cp)
         self.failUnless(self.cp.__dict__.has_key('groups'))
@@ -68,18 +76,12 @@ class TestPortalCreation(PloneTestCase.PloneTestCase):
 
     def testReplyTabIsOff(self):
         # Ensure 'reply' tab is turned off
-        # NOTE: ActionProviderBAse should have a 'getActionById'
-        # that does this for x in: if x == id
-        dt_actions = self.portal.portal_discussion.listActions()
-        reply_visible=1
-        for action in dt_actions:
-            if action.id=='reply':
-                reply_visible=action.visible
-        self.assertEqual(reply_visible, 0)
+        dtool = self.portal.portal_discussion
+        self.assertEqual(dtool.getActionInfo('object/reply')['visible'], False)
 
     def testLargePloneFolderWorkflow(self):
         # Large Plone Folder should use folder_workflow
-        # http://plone.org/collector/2744
+        # http://dev.plone.org/plone/ticket/2744
         lpf_chain = self.workflow.getChainFor('Large Plone Folder')
         self.failUnless('folder_workflow' in lpf_chain)
         self.failIf('plone_workflow' in lpf_chain)
@@ -103,7 +105,7 @@ class TestPortalCreation(PloneTestCase.PloneTestCase):
 
     def testMembersFolderIsIndexed(self):
         # Members folder should be cataloged
-        res = self.catalog(id='Members')
+        res = self.catalog(getId='Members')
         self.assertEqual(len(res), 1)
         self.assertEqual(res[0].getId, 'Members')
         self.assertEqual(res[0].Title, 'Members')
@@ -183,11 +185,7 @@ class TestPortalCreation(PloneTestCase.PloneTestCase):
 
     def testFullScreenAction(self):
         # There should be a full_screen action
-        for action in self.actions.listActions():
-            if action.getId() == 'full_screen':
-                break
-        else:
-            self.fail("Actions tool has no 'full_screen' action")
+        self.failUnless(self.actions.getActionInfo('document_actions/full_screen') is not None)
 
     def testFullScreenActionIcon(self):
         # There should be a full_screen action icon
@@ -260,7 +258,7 @@ class TestPortalCreation(PloneTestCase.PloneTestCase):
 
     def testNewsFolderIsIndexed(self):
         # News (smart) folder should be cataloged
-        res = self.catalog(id='news')
+        res = self.catalog(getId='news')
         self.assertEqual(len(res), 1)
         self.assertEqual(res[0].getId, 'news')
         self.assertEqual(res[0].Title, 'News')
@@ -310,11 +308,12 @@ class TestPortalCreation(PloneTestCase.PloneTestCase):
         self.assertEqual(query['start']['range'], 'max')
 
     def testObjectButtonActions(self):
-        installed = [(a.getId(), a.getCategory()) for a in self.actions.listActions()]
-        self.failUnless(('cut', 'object_buttons') in installed)
-        self.failUnless(('copy', 'object_buttons') in installed)
-        self.failUnless(('paste', 'object_buttons') in installed)
-        self.failUnless(('delete', 'object_buttons') in installed)
+        self.setRoles(['Manager', 'Member'])
+        atool = self.actions
+        self.failIf(atool.getActionInfo('object_buttons/cut') is None)
+        self.failIf(atool.getActionInfo('object_buttons/copy') is None)
+        self.failIf(atool.getActionInfo('object_buttons/paste') is None)
+        self.failIf(atool.getActionInfo('object_buttons/delete') is None)
 
     def testContentsTabVisible(self):
         for a in self.actions.listActions():
@@ -334,7 +333,10 @@ class TestPortalCreation(PloneTestCase.PloneTestCase):
 
     def testAllDependenciesMet(self):
         from Products.CMFPlone.setup import dependencies
-        msgs = [x for x in dependencies.messages if not x['optional']]
+        # filter out the unknown Zope version message
+        msgs = [x for x in dependencies.messages if
+                  not x['message'].startswith('Unable to detect Zope version.')]
+        msgs = [x for x in msgs if not x['optional']]
         self.failUnlessEqual(msgs, [])
 
     def testDisableFolderSectionsSiteProperty(self):
@@ -396,8 +398,10 @@ class TestPortalCreation(PloneTestCase.PloneTestCase):
     def testFolderlistingAction(self):
         # Make sure the folderlisting action of a Folder is /view, to ensure
         # that the layout template will be resolved (see PloneTool.browserDefault)
-        self.assertEqual(self.types['Folder'].getActionById('folderlisting'), 'view')
-        self.assertEqual(self.types['Plone Site'].getActionById('folderlisting'), 'view')
+        self.assertEqual(self.types['Folder'].getActionObject('folder/folderlisting').getActionExpression(),
+                         'string:${folder_url}/view')
+        self.assertEqual(self.types['Plone Site'].getActionObject('folder/folderlisting').getActionExpression(),
+                         'string:${folder_url}/view')
 
     def testEnableLivesearchProperty(self):
         # site_properties should have enable_livesearch property
@@ -411,12 +415,6 @@ class TestPortalCreation(PloneTestCase.PloneTestCase):
         else:
             self.fail("Action icons tool has no 'SearchSettings' icon")
 
-    def testCookieCrumblerProperties(self):
-        # Cookie Crumbler should have unauth_page set to insufficient privileges
-        # and the auto login page restored to login_form
-        self.assertEqual(self.cc.getProperty('unauth_page'), 'insufficient_privileges')
-        self.assertEqual(self.cc.getProperty('auto_login_page'), 'login_form')
-
     def testPortalFTIIsDynamicFTI(self):
         # Plone Site FTI should be a DynamicView FTI
         fti = self.portal.getTypeInfo()
@@ -436,15 +434,20 @@ class TestPortalCreation(PloneTestCase.PloneTestCase):
         self.assertEqual(aliases, expected_aliases)
 
     def testSiteActions(self):
-        installed = [(a.getId(), a.getCategory()) for a in self.actions.listActions()]
-        self.failUnless(('sitemap', 'site_actions') in installed)
-        self.failUnless(('contact', 'site_actions') in installed)
-        self.failUnless(('accessibility', 'site_actions') in installed)
-        self.failUnless(('plone_setup', 'site_actions') in installed)
+        self.setRoles(['Manager', 'Member'])
+        atool = self.actions
+        self.failIf(atool.getActionInfo('site_actions/sitemap') is None)
+        self.failIf(atool.getActionInfo('site_actions/contact') is None)
+        self.failIf(atool.getActionInfo('site_actions/accessibility') is None)
+        self.failIf(atool.getActionInfo('site_actions/plone_setup') is None)
 
     def testNoMembershipToolPloneSetupAction(self):
-        installed = [a.getId() for a in self.membership.listActions()]
-        self.failIf('plone_setup' in installed)
+        try:
+            self.failUnless(self.actions.getActionInfo('user/plone_setup'))
+        except ValueError:
+            pass
+        else:
+            self.fail('Found plone_setup action in user category.')
 
     def testTypesHaveSelectedLayoutViewAction(self):
         # Should add method aliases to the Plone Site FTI
@@ -535,10 +538,17 @@ class TestPortalCreation(PloneTestCase.PloneTestCase):
         acts = self.actions.listFilteredActionsFor(self.folder.index_html)
         buttons = acts['object_buttons']
         self.assertEqual(len(buttons), 4)
-        urls = [(a['id'],a['url']) for a in buttons]
+        # special case for delete which needs a confirmation form
+        urls = [(a['id'],a['url']) for a in buttons
+                if a['id'] != 'delete']
         for url in urls:
             # ensure that e.g. the 'copy' url contains object_copy
             self.failUnless('object_'+url[0] in url[1], "%s does not perform the expected object_%s action"%(url[0],url[0]))
+        
+        delete_action = [(a['id'],a['url']) for a in buttons
+                if a['id'] == 'delete'][0]
+        self.failUnless('delete_confirmation' in delete_action[1],
+                         "object_delete does not use the confirmation form")
 
     def testObjectButtonActionsInExpectedOrder(self):
         # The object buttons need to be in a standardized order
@@ -595,6 +605,10 @@ class TestPortalCreation(PloneTestCase.PloneTestCase):
         path = [x.strip() for x in path.split(',')]
         self.assertEqual(path[-1], 'cmf_legacy')
 
+    def testCustomSkinFolderExists(self):
+        # the custom skin needs to be created
+        self.failUnless('custom' in self.skins.objectIds())
+
     def testMemberHasViewGroupsPermission(self):
         # Member should be granted the 'View Groups' permission
         member_has_permission = [p for p in
@@ -625,7 +639,7 @@ class TestPortalCreation(PloneTestCase.PloneTestCase):
         # The safe_html transformation should be configurable
         try:
             self.transforms.safe_html.get_parameter_value('disable_transform')
-        except (AttrbuteError, KeyError):
+        except (AttributeError, KeyError):
             self.fail('safe_html transformation not updated')
 
     def testNavtreePropertiesNormalized(self):
@@ -633,7 +647,7 @@ class TestPortalCreation(PloneTestCase.PloneTestCase):
         toRemove = ['skipIndex_html', 'showMyUserFolderOnly', 'showFolderishSiblingsOnly',
                     'showFolderishChildrenOnly', 'showNonFolderishObject', 'showTopicResults',
                     'rolesSeeContentView', 'rolesSeeUnpublishedContent', 'rolesSeeContentsView ',
-                    'batchSize', 'sortCriteria', 'croppingLength', 'forceParentsInBatch', 
+                    'batchSize', 'sortCriteria', 'croppingLength', 'forceParentsInBatch',
                     'rolesSeeHiddenContent', 'typesLinkToFolderContents']
         toAdd = {'name' : '', 'root' : '/', 'currentFolderOnlyInNavtree' : False}
         for property in toRemove:
@@ -661,6 +675,33 @@ class TestPortalCreation(PloneTestCase.PloneTestCase):
         assertIcon('paste')
         assertIcon('delete')
 
+    def testCacheManagers(self):
+        # The cache and caching policy managers should exist
+        httpcache = self.portal._getOb('HTTPCache', None)
+        ramcache = self.portal._getOb('RAMCache', None)
+        cpm = self.portal._getOb('caching_policy_manager', None)
+        self.failUnless(isinstance(httpcache, AcceleratedHTTPCacheManager))
+        self.failUnless(isinstance(ramcache, RAMCacheManager))
+        self.failUnless(isinstance(cpm, CachingPolicyManager))
+
+    def testHomeActionUsesView(self):
+        actions = self.portal.portal_actions.listActions()
+        homeAction = [x for x in actions if x.id == 'index_html'][0]
+        self.assertEquals(homeAction.getActionExpression(), 'string:${globals_view/navigationRootUrl}')
+
+    def testPloneLexicon(self):
+        # Plone lexicon should use new splitter and case normalizer
+        pipeline = self.catalog.plone_lexicon._pipeline
+        self.failUnless(len(pipeline) >= 2)
+        self.failUnless(isinstance(pipeline[0], Splitter))
+        self.failUnless(isinstance(pipeline[1], CaseNormalizer))
+
+    def testMakeSnapshot(self):
+        # GenericSetup snapshot should work
+        self.setRoles(['Manager'])
+        snapshot_id = self.setup._mangleTimestampName('test')
+        self.setup.createSnapshot(snapshot_id)
+
 
 class TestPortalBugs(PloneTestCase.PloneTestCase):
 
@@ -668,8 +709,7 @@ class TestPortalBugs(PloneTestCase.PloneTestCase):
         self.membership = self.portal.portal_membership
         self.members = self.membership.getMembersFolder()
         self.catalog = self.portal.portal_catalog
-        # Fake the Members folder contents
-        self.members._setObject('index_html', ZopePageTemplate('index_html'))
+        self.mem_index_type = "Script (Python)"
 
     def testMembersIndexHtml(self):
         # index_html for Members folder should be a Page Template
@@ -678,14 +718,14 @@ class TestPortalBugs(PloneTestCase.PloneTestCase):
         self.assertEqual(aq_base(members).meta_type, 'ATBTreeFolder')
         self.failUnless(hasattr(aq_base(members), 'index_html'))
         # getitem works
-        self.assertEqual(aq_base(members)['index_html'].meta_type, 'Page Template')
-        self.assertEqual(members['index_html'].meta_type, 'Page Template')
+        self.assertEqual(aq_base(members)['index_html'].meta_type, self.mem_index_type)
+        self.assertEqual(members['index_html'].meta_type, self.mem_index_type)
         # _getOb works
-        self.assertEqual(aq_base(members)._getOb('index_html').meta_type, 'Page Template')
-        self.assertEqual(members._getOb('index_html').meta_type, 'Page Template')
+        self.assertEqual(aq_base(members)._getOb('index_html').meta_type, self.mem_index_type)
+        self.assertEqual(members._getOb('index_html').meta_type, self.mem_index_type)
         # getattr works when called explicitly
-        self.assertEqual(aq_base(members).__getattr__('index_html').meta_type, 'Page Template')
-        self.assertEqual(members.__getattr__('index_html').meta_type, 'Page Template')
+        self.assertEqual(aq_base(members).__getattr__('index_html').meta_type, self.mem_index_type)
+        self.assertEqual(members.__getattr__('index_html').meta_type, self.mem_index_type)
 
     def testLargePloneFolderHickup(self):
         # Attribute access for 'index_html' acquired the Document from the
@@ -695,7 +735,7 @@ class TestPortalBugs(PloneTestCase.PloneTestCase):
         members = self.members
         self.assertEqual(aq_base(members).meta_type, 'ATBTreeFolder')
         #self.assertEqual(members.index_html.meta_type, 'Document')
-        self.assertEqual(members.index_html.meta_type, 'Page Template')
+        self.assertEqual(members.index_html.meta_type, self.mem_index_type)
 
     def testManageBeforeDeleteIsCalledRecursively(self):
         # When the portal is deleted, all subobject should have
@@ -705,9 +745,31 @@ class TestPortalBugs(PloneTestCase.PloneTestCase):
         self.app._delObject(PloneTestCase.portal_name)
         self.failUnless(self.foo.before_delete_called())
 
+    def testSubsequentProfileImportSucceeds(self):
+        # Subsequent profile imports fail (#5439)
+        self.loginAsPortalOwner()
+        setup_tool = self.portal.portal_setup
+        setup_tool.runAllImportSteps() # this will raise an error if it fails
+        self.failUnless(1 == 1)
+
+    def testFinalStepsWithMembersFolderDeleted(self):
+        # We want the final steps to work even if the 'Members' folder
+        # is gone
+        self.loginAsPortalOwner()
+        portal = self.portal
+        portal.manage_delObjects(['Members'])
+        class FakeContext:
+            def getSite(self):
+                return portal
+            def readDataFile(self, filename):
+                return True # Anything other than None runs the step
+
+        setuphandlers.importFinalSteps(FakeContext()) # raises error if fail
+        self.failUnless(1 == 1)
+
     def testExportImportLosesTextIndexes(self):
         # Importing a portal .zexp loses text indexes? (#4803)
-        self.loginPortalOwner()
+        self.loginAsPortalOwner()
         tempfile = mkstemp('.zexp')
         tempname = tempfile[1]
         try:
